@@ -18,7 +18,7 @@ class ftpUtil:
     __url_head="http://home.hddly.cn:90/stud/"
     __mutil= mysqlUtil()
 
-    def putfile_project(self, local_path, prj_id, stud_id, no_file,fdesc):
+    def putfile_project(self, local_path, prj_id, stud_id, no_file,fdesc,surl):
         # # 要传输文件的路径
         # filepath = "./myname.jpg"
         # # 上传后的传输文件的文件名
@@ -69,12 +69,14 @@ class ftpUtil:
                                        fdesc,
                                        fsize,
                                        duration,
-                                       ftype,pid)
+                                       ftype,
+                                       pid,
+                                       surl)
         except Exception as ex:
             print("sftp_file_ins error:%s" % ex)
 
     def putfile_stud(self,local_path,prj_id,stud_id,no_file):
-        self.putfile_project(local_path,prj_id,stud_id,no_file,'');
+        self.putfile_project(local_path,prj_id,stud_id,no_file,'','');
 
 
     def putfile_media(self,local_path,remote_file):
